
Changelog
=========

0.0.0 (2020-05-13)
------------------

* First release on PyPI.


0.0.1 (2020-05-19)
------------------

* First working version, using the (Ozlen et al., 2014) algorithm, for minimisation problems.


0.0.2 (2020-05-19)
------------------

* Implemented maximisation problem solving.
* Improved documentation.
* Improved testing suite.


0.0.3 (2021-11-24)
------------------

* New state of the art algorithm - two stage approach from (Tamby & Vanderpooten, 2020) - implemented and set as the default for the command line executable.


0.0.4 (2021-11-24)
------------------

* Documentation and changelog changes that were missed in previous release.
